@@ -333,6 +333,13 @@ man_pages = [
         [author],
         1,
     ),
+    (
+        "user_guide/commands/barman/list_processes.inc",
+        "barman-list-processes",
+        "Barman Sub-Commands",
+        [author],
+        1,
+    ),
     (
         "user_guide/commands/barman/list_servers.inc",
         "barman-list-servers",
@@ -438,6 +445,13 @@ man_pages = [
         [author],
         1,
     ),
+    (
+        "user_guide/commands/barman/terminate_process.inc",
+        "barman-terminate-process",
+        "Barman Sub-Commands",
+        [author],
+        1,
+    ),
     (
         "user_guide/commands/barman/verify_backup.inc",
         "barman-verify-backup",
