@@ -17,12 +17,19 @@
 # along with Barman.  If not, see <http://www.gnu.org/licenses/>.
 
 import base64
+import bz2
+import gzip
 import io
+import logging
+import lzma
 import os
 import tarfile
 
+import cramjam
+import lz4.frame
 import mock
 import pytest
+import zstandard
 from testing_helpers import build_mocked_server, get_compression_config
 
 from barman.compression import (
@@ -43,6 +50,7 @@ from barman.compression import (
     PgBaseBackupCompressionOption,
     PyBZip2Compressor,
     PyGZipCompressor,
+    SnappyCompressor,
     XZCompressor,
     ZSTDCompression,
     ZSTDCompressor,
@@ -136,7 +144,7 @@ class TestCompressionManager(object):
         assert comp_manager.unidentified_compression is None
 
         # AND the value of MAGIC_MAX_LENGTH equals the length of the magic bytes
-        assert comp_manager.MAGIC_MAX_LENGTH == 6
+        assert comp_manager.MAGIC_MAX_LENGTH == 10
 
     def test_get_compressor_custom_nomagic(self, _reset_custom_compressor):
         # GIVEN a Barman config which specifies custom compression
@@ -163,7 +171,7 @@ class TestCompressionManager(object):
 
         # AND the value of MAGIC_MAX_LENGTH equals the max length of the default
         # compressions
-        assert comp_manager.MAGIC_MAX_LENGTH == 6
+        assert comp_manager.MAGIC_MAX_LENGTH == 10
 
     def test_get_compressor_gzip(self):
         # prepare mock obj
@@ -269,6 +277,50 @@ class TestCompressor(object):
         # THEN validate returns True
         assert Compressor.validate(bytes_to_validate) is is_valid
 
+    @pytest.mark.parametrize(
+        "compression_level, expected, issue_log",
+        [
+            # Case 1: a level greater than LEVEL_MAX defaults to LEVEL_MAX
+            (10, GZipCompressor.LEVEL_MAX, True),
+            # Case 2: a level lower than LEVEL_MIN defaults to LEVEL_MIN
+            (0, GZipCompressor.LEVEL_MIN, True),
+            # Case 3: a level in the range is correctly set
+            (7, 7, False),
+            # Case 4: literal value of `low` is set as defined in LEVEL_LOW
+            ("low", GZipCompressor.LEVEL_LOW, False),
+            # Case 5: literal value of `high` is set as defined in LEVEL_HIGH
+            ("high", GZipCompressor.LEVEL_HIGH, False),
+            # Case 6: literal value of `medium` is set as defined in LEVEL_MEDIUM
+            ("medium", GZipCompressor.LEVEL_MEDIUM, False),
+            # Case 7: any value that is not recognized also defaults to LEVEL_MEDIUM
+            ("nonsense", GZipCompressor.LEVEL_MEDIUM, False),
+        ],
+    )
+    def test_compression_level_is_set_correctly(
+        self, compression_level, expected, issue_log, caplog
+    ):
+        """
+        Asserts that the compression level is set correctly when instantiating a
+        compressor.
+
+        .. note::
+            ``GZipCompressor`` is used in this test because we cannot instantiate
+            the abstract ``Compressor`` class. However, the tested logic resides in
+            the ``Compressor`` class and applies to all its subclasses.
+        """
+        caplog.set_level(logging.DEBUG)
+        mock_config = mock.Mock(compression="gzip", compression_level=compression_level)
+        compressor = GZipCompressor(mock_config, "gzip")
+        assert compressor is not None
+        assert compressor.level == expected
+        if issue_log:
+            msg = "Compression level %s out of range for %s, using %s instead" % (
+                compression_level,
+                "gzip",
+                expected,
+            )
+            assert msg in caplog.text
+
 
 # noinspection PyMethodMayBeStatic
 class TestCommandCompressors(object):
@@ -477,6 +529,93 @@ class TestInternalCompressors(object):
         f = open(LZ4_FILE_UNCOMPRESSED % tmpdir.strpath).read()
         assert f == "content"
 
+    @pytest.mark.parametrize(
+        "compression, compression_class",
+        [
+            ("pygzip", PyGZipCompressor),
+            ("pybzip2", PyBZip2Compressor),
+            ("xz", XZCompressor),
+            ("zstd", ZSTDCompressor),
+            ("lz4", LZ4Compressor),
+            ("snappy", SnappyCompressor),
+        ],
+    )
+    def test_compress_in_mem(self, compression, compression_class):
+        """
+        Test the ``compress_in_mem`` method of the compression classes
+        """
+        # GIVEN a compressor instance
+        config_mock = mock.Mock(compression=compression)
+        compressor = compression_class(config=config_mock, compression=compression)
+        # AND some data to compress
+        uncompressed = io.BytesIO(b"I'm a big file. Compress me!")
+        # WHEN compress_in_mem is called
+        compressed = compressor.compress_in_mem(uncompressed)
+        # THEN the compressed data starts with the expected magic bytes, meaning it was
+        # compressed successfully
+        assert compressed.read().startswith(compression_class.MAGIC)
+
+    @pytest.mark.parametrize(
+        "compression, compression_class, compressed_fileobj",
+        [
+            ("pygzip", PyGZipCompressor, io.BytesIO(gzip.compress(b"data"))),
+            ("pybzip2", PyBZip2Compressor, io.BytesIO(bz2.compress(b"data"))),
+            ("xz", XZCompressor, io.BytesIO(lzma.compress(b"data"))),
+            ("lz4", LZ4Compressor, io.BytesIO(lz4.frame.compress(b"data"))),
+            ("snappy", SnappyCompressor, io.BytesIO(cramjam.snappy.compress(b"data"))),
+            (
+                "zstd",
+                ZSTDCompressor,
+                io.BytesIO(zstandard.ZstdCompressor().compress(b"data")),
+            ),
+        ],
+    )
+    def test_decompress_in_mem(
+        self, compression, compression_class, compressed_fileobj
+    ):
+        """
+        Test the ``decompress_in_mem`` method of the compression classes
+        """
+        # GIVEN a compressor instance
+        config_mock = mock.Mock(compression=compression)
+        compressor = compression_class(config=config_mock, compression=compression)
+        # WHEN decompress_in_mem is called
+        compressed_fileobj.seek(0)
+        decompressed_data = compressor.decompress_in_mem(compressed_fileobj)
+        # THEN the decompressed data matches the original data
+        assert decompressed_data.read() == b"data"
+
+    @pytest.mark.parametrize(
+        "compression, compression_class",
+        [
+            ("pygzip", PyGZipCompressor),
+            ("pybzip2", PyBZip2Compressor),
+            ("xz", XZCompressor),
+            ("zstd", ZSTDCompressor),
+            ("lz4", LZ4Compressor),
+        ],
+    )
+    @mock.patch("barman.compression.shutil")
+    def test_decompress_to_fileobj(self, mock_shutil, compression, compression_class):
+        """
+        Test the ``decompress_to_fileobj`` method of the compression classes.
+        """
+        # GIVEN a compressor instance
+        config_mock = mock.Mock(compression=compression)
+        compressor = compression_class(config=config_mock, compression=compression)
+        # AND mock the decompress_in_mem object of the compressor class
+        with mock.patch.object(compressor, "decompress_in_mem") as mock_decompress:
+            mock_decompress.return_value = io.BytesIO(b"decompressed")
+            compressed_fileobj = io.BytesIO(b"compressed")
+            dest_fileobj = io.BytesIO()
+            # THEN calling decompress_to_fileobj is just a matter of calling
+            # decompress_in_mem and then copying its result to the dest file-object
+            compressor.decompress_to_fileobj(compressed_fileobj, dest_fileobj)
+            mock_decompress.assert_called_once_with(compressed_fileobj)
+            mock_shutil.copyfileobj.assert_called_once_with(
+                mock_decompress.return_value, dest_fileobj
+            )
+
 
 # noinspection PyMethodMayBeStatic
 class TestCustomCompressor(object):
