@@ -72,6 +72,7 @@ TEST_CONFIG_BARMAN = """
 barman_home = /some/barman/home
 barman_user = {USER}
 compression = gzip
+compression_level = medium
 log_file = /some/barman/home/log/barman.log
 log_level = INFO
 retention_policy = redundancy 2
@@ -203,6 +204,7 @@ class TestConfigMapping(object):
                 "barman_home": "/etc/barman.conf",
                 "barman_user": "/etc/barman.conf",
                 "compression": "/etc/barman.conf",
+                "compression_level": "/etc/barman.conf",
                 "log_file": "/etc/barman.conf",
                 "log_level": "/etc/barman.conf",
                 "retention_policy": "/etc/barman.conf",
@@ -350,6 +352,7 @@ class TestConfig(object):
                 "backup_compression_location": None,
                 "backup_compression_workers": None,
                 "compression": "gzip",
+                "compression_level": "medium",
                 "last_backup_maximum_age": timedelta(1),
                 "last_backup_minimum_size": 1048576,
                 "last_wal_maximum_age": timedelta(hours=1),
@@ -389,6 +392,7 @@ class TestConfig(object):
                 "backup_compression_workers": None,
                 "cluster": "web",
                 "compression": None,
+                "compression_level": "medium",
                 "conninfo": "host=web01 user=postgres port=5432",
                 "description": "Web applications database",
                 "incoming_wals_directory": "/some/barman/home/web/incoming",
@@ -776,6 +780,7 @@ class TestConfig(object):
             "barman_home": "/some/barman/home",
             "barman_user": "barman",
             "compression": "gzip",
+            "compression_level": "medium",
             "log_file": "/some/barman/home/log/barman.log",
             "log_level": "INFO",
             "retention_policy": "redundancy 2",
@@ -790,6 +795,7 @@ class TestConfig(object):
             "wal_retention_policy": "base",
             "retention_policy": "redundancy 2",
             "compression": "gzip",
+            "compression_level": "medium",
             "barman_user": "barman",
             "log_file": "/some/barman/home/log/barman.log",
             "archiver": "True",
@@ -1040,6 +1046,7 @@ class TestServerConfig(object):
             "barman_home": "/some/barman/home",
             "barman_user": "barman",
             "compression": "gzip",
+            "compression_level": "medium",
             "log_file": "/some/barman/home/log/barman.log",
             "log_level": "INFO",
             "retention_policy": "redundancy 2",
@@ -1086,6 +1093,7 @@ class TestServerConfig(object):
             "wal_retention_policy": "base",
             "retention_policy": "redundancy 3",
             "compression": "gzip",
+            "compression_level": "medium",
             "backup_compression": "none",
             "wals_directory": "wals",
             "xlogdb_directory": "wals",
@@ -1365,6 +1373,7 @@ class TestModelConfig:
             "check_timeout": None,
             "cluster": "SOME_CLUSTER",
             "compression": None,
+            "compression_level": None,
             "conninfo": "SOME_CONNINFO",
             "create_slot": None,
             "custom_compression_filter": None,
@@ -1372,6 +1381,9 @@ class TestModelConfig:
             "custom_decompression_filter": None,
             "description": None,
             "disabled": None,
+            "encryption": None,
+            "encryption_key_id": None,
+            "encryption_passphrase_command": None,
             "forward_config_path": None,
             "gcp_project": None,
             "gcp_zone": None,
@@ -1465,6 +1477,7 @@ class TestModelConfig:
             "check_timeout": {"source": "SOME_SOURCE", "value": None},
             "cluster": {"source": "SOME_SOURCE", "value": "SOME_CLUSTER"},
             "compression": {"source": "SOME_SOURCE", "value": None},
+            "compression_level": {"source": "SOME_SOURCE", "value": None},
             "conninfo": {"source": "SOME_SOURCE", "value": "SOME_CONNINFO"},
             "create_slot": {"source": "SOME_SOURCE", "value": None},
             "custom_compression_filter": {"source": "SOME_SOURCE", "value": None},
@@ -1472,6 +1485,9 @@ class TestModelConfig:
             "custom_decompression_filter": {"source": "SOME_SOURCE", "value": None},
             "description": {"source": "SOME_SOURCE", "value": None},
             "disabled": {"source": "SOME_SOURCE", "value": None},
+            "encryption": {"source": "SOME_SOURCE", "value": None},
+            "encryption_key_id": {"source": "SOME_SOURCE", "value": None},
+            "encryption_passphrase_command": {"source": "SOME_SOURCE", "value": None},
             "forward_config_path": {"source": "SOME_SOURCE", "value": None},
             "gcp_project": {"source": "SOME_SOURCE", "value": None},
             "gcp_zone": {"source": "SOME_SOURCE", "value": None},
