@@ -48,6 +48,7 @@ from barman.infofile import (
     FieldListFile,
     LocalBackupInfo,
     SyntheticBackupInfo,
+    VolatileBackupInfo,
     WalFileInfo,
     dump_backup_ids,
     load_backup_ids,
@@ -270,107 +271,192 @@ class TestFieldListFile(object):
 
 # noinspection PyMethodMayBeStatic
 class TestWalFileInfo(object):
+    @mock.patch("barman.encryption.EncryptionManager")
     @mock.patch("barman.compression.CompressionManager")
-    def test_from_file_no_compression(self, mock_compression_manager, tmpdir):
+    def test_from_file_no_compression(
+        self, mock_compression_manager, mock_encryption_manager, tmpdir
+    ):
         tmp_file = tmpdir.join("000000000000000000000001")
         tmp_file.write("dummy_content\n")
         stat = os.stat(tmp_file.strpath)
-        wfile_info = WalFileInfo.from_file(tmp_file.strpath, mock_compression_manager)
+        wfile_info = WalFileInfo.from_file(
+            filename=tmp_file.strpath,
+            compression_manager=mock_compression_manager,
+            encryption_manager=mock_encryption_manager,
+        )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == stat.st_size
         assert wfile_info.time == stat.st_mtime
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
+    @mock.patch("barman.encryption.EncryptionManager")
     @mock.patch("barman.compression.CompressionManager")
-    def test_from_file_compression(self, mock_compression_manager, tmpdir):
+    def test_from_file_compression(
+        self, mock_compression_manager, mock_encryption_manager, tmpdir
+    ):
         # prepare
         mock_compression_manager.identify_compression.return_value = "test_compression"
 
         tmp_file = tmpdir.join("000000000000000000000001")
         tmp_file.write("dummy_content\n")
-        wfile_info = WalFileInfo.from_file(tmp_file.strpath, mock_compression_manager)
+        wfile_info = WalFileInfo.from_file(
+            filename=tmp_file.strpath,
+            compression_manager=mock_compression_manager,
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
+        )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == tmp_file.size()
         assert wfile_info.time == tmp_file.mtime()
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
+        assert wfile_info.encryption is None
         assert wfile_info.compression == "test_compression"
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
+    @mock.patch("barman.encryption.EncryptionManager")
     @mock.patch("barman.compression.CompressionManager")
-    def test_from_file_unidentified_compression(self, mock_compression_manager, tmpdir):
+    def test_from_file_unidentified_compression(
+        self, mock_compression_manager, mock_encryption_manager, tmpdir
+    ):
         # prepare
         mock_compression_manager.identify_compression.return_value = None
         tmp_file = tmpdir.join("00000001000000E500000064")
         tmp_file.write("dummy_content\n")
         wfile_info = WalFileInfo.from_file(
-            tmp_file.strpath,
-            mock_compression_manager,
+            filename=tmp_file.strpath,
+            compression_manager=mock_compression_manager,
             unidentified_compression="test_unidentified_compression",
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
         )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == tmp_file.size()
         assert wfile_info.time == tmp_file.mtime()
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
+        assert wfile_info.encryption is None
         assert wfile_info.compression == "test_unidentified_compression"
         assert wfile_info.relpath() == ("00000001000000E5/00000001000000E500000064")
 
+    @mock.patch("barman.encryption.EncryptionManager")
     @mock.patch("barman.compression.CompressionManager")
-    def test_from_file_override_compression(self, mock_compression_manager, tmpdir):
+    def test_from_file_override_compression(
+        self, mock_compression_manager, mock_encryption_manager, tmpdir
+    ):
         # prepare
         mock_compression_manager.identify_compression.return_value = None
 
         tmp_file = tmpdir.join("000000000000000000000001")
         tmp_file.write("dummy_content\n")
         wfile_info = WalFileInfo.from_file(
-            tmp_file.strpath,
-            mock_compression_manager,
+            filename=tmp_file.strpath,
+            compression_manager=mock_compression_manager,
             compression="test_override_compression",
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
         )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == tmp_file.size()
         assert wfile_info.time == tmp_file.mtime()
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
+        assert wfile_info.encryption is None
         assert wfile_info.compression == "test_override_compression"
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
+    @mock.patch("barman.encryption.EncryptionManager")
     @mock.patch("barman.compression.CompressionManager")
-    def test_from_file_override(self, compression_manager, tmpdir):
+    def test_from_file_override(
+        self, compression_manager, mock_encryption_manager, tmpdir
+    ):
         # prepare
         compression_manager.identify_compression.return_value = None
         compression_manager.unidentified_compression = None
-
+        mock_encryption_manager.identify_encryption.return_vale = None
         tmp_file = tmpdir.join("000000000000000000000001")
         tmp_file.write("dummy_content\n")
 
         wfile_info = WalFileInfo.from_file(
-            tmp_file.strpath, compression_manager, name="000000000000000000000002"
+            filename=tmp_file.strpath,
+            compression_manager=compression_manager,
+            name="000000000000000000000002",
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
         )
         assert wfile_info.name == "000000000000000000000002"
         assert wfile_info.size == tmp_file.size()
         assert wfile_info.time == tmp_file.mtime()
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
         assert wfile_info.compression is None
+        assert wfile_info.encryption is None
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000002")
 
         wfile_info = WalFileInfo.from_file(
-            tmp_file.strpath, compression_manager, size=42
+            filename=tmp_file.strpath,
+            compression_manager=compression_manager,
+            size=42,
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
         )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == 42
         assert wfile_info.time == tmp_file.mtime()
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
         assert wfile_info.compression is None
+        assert wfile_info.encryption is None
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
         wfile_info = WalFileInfo.from_file(
-            tmp_file.strpath, compression_manager, time=43
+            filename=tmp_file.strpath,
+            compression_manager=compression_manager,
+            time=43,
+            encryption_manager=mock_encryption_manager,
+            encryption=None,
         )
         assert wfile_info.name == tmp_file.basename
         assert wfile_info.size == tmp_file.size()
         assert wfile_info.time == 43
         assert wfile_info.filename == "%s.meta" % tmp_file.strpath
         assert wfile_info.compression is None
+        assert wfile_info.encryption is None
+        assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
+
+    @mock.patch("barman.encryption.EncryptionManager")
+    def test_from_file_encryption(self, mock_encryption_manager, tmpdir):
+        # prepare
+        mock_encryption_manager.identify_encryption.return_value = "test_encryption"
+
+        tmp_file = tmpdir.join("000000000000000000000001")
+        tmp_file.write("dummy_content\n")
+        wfile_info = WalFileInfo.from_file(
+            tmp_file.strpath,
+            encryption_manager=mock_encryption_manager,
+        )
+        assert wfile_info.name == tmp_file.basename
+        assert wfile_info.size == tmp_file.size()
+        assert wfile_info.time == tmp_file.mtime()
+        assert wfile_info.filename == "%s.meta" % tmp_file.strpath
+        assert wfile_info.compression is None
+        assert wfile_info.encryption == "test_encryption"
+        assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
+
+    @mock.patch("barman.encryption.EncryptionManager")
+    def test_from_file_override_encryption(self, encryption_manager, tmpdir):
+        # prepare
+        encryption_manager.identify_encryption.return_value = None
+
+        tmp_file = tmpdir.join("000000000000000000000001")
+        tmp_file.write("dummy_content\n")
+        wfile_info = WalFileInfo.from_file(
+            tmp_file.strpath,
+            encryption_manager=encryption_manager,
+            encryption="test_override_encryption",
+        )
+        assert wfile_info.name == tmp_file.basename
+        assert wfile_info.size == tmp_file.size()
+        assert wfile_info.time == tmp_file.mtime()
+        assert wfile_info.filename == "%s.meta" % tmp_file.strpath
+        assert wfile_info.compression is None
+        assert wfile_info.encryption == "test_override_encryption"
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
     def test_to_xlogdb_line(self):
@@ -379,10 +465,11 @@ class TestWalFileInfo(object):
         wfile_info.size = 42
         wfile_info.time = 43
         wfile_info.compression = None
+        wfile_info.encryption = None
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000002")
 
         assert wfile_info.to_xlogdb_line() == (
-            "000000000000000000000002\t42\t43\tNone\n"
+            "000000000000000000000002\t42\t43\tNone\tNone\n"
         )
 
     def test_from_xlogdb_line(self):
@@ -395,6 +482,7 @@ class TestWalFileInfo(object):
         wfile_info.size = 42
         wfile_info.time = 43
         wfile_info.compression = None
+        wfile_info.encryption = None
         assert wfile_info.relpath() == ("0000000000000000/000000000000000000000001")
 
         # mock a server object
@@ -403,7 +491,7 @@ class TestWalFileInfo(object):
 
         # parse the string
         info_file = wfile_info.from_xlogdb_line(
-            "000000000000000000000001\t42\t43\tNone\n"
+            "000000000000000000000001\t42\t43\tNone\tNone\n"
         )
 
         assert list(wfile_info.items()) == list(info_file.items())
@@ -1491,3 +1579,69 @@ class TestSyntheticBackupInfo:
         )
         directory = backup_info.get_basebackup_directory()
         assert directory == "/fake/path/fake_name"
+
+
+class TestVolatileBackupInfo:
+    """
+    Unit tests for the :class:`VolatileBackupInfo` class.
+    """
+
+    @mock.patch("barman.infofile.LocalBackupInfo.__init__", return_value=None)
+    def test_volatile_backup_info_init_calls_super(self, mock_local_backup_info_init):
+        """
+        Test that :class:`VolatileBackupInfo` correctly calls the superclass
+        :class:`LocalBackupInfo` during initialization.
+        """
+        server = build_mocked_server()
+        base_directory = "/fake/path/"
+        backup_id = "fake_backup_id"
+
+        # Initialize VolatileBackupInfo
+        volatile_backup_info = VolatileBackupInfo(
+            server=server,
+            base_directory=base_directory,
+            backup_id=backup_id,
+        )
+
+        # Assert that the superclass __init__ was called with the correct arguments
+        mock_local_backup_info_init.assert_called_once_with(
+            server,
+            None,
+            backup_id,
+        )
+
+        # Ensure the object is an instance of VolatileBackupInfo
+        assert isinstance(volatile_backup_info, VolatileBackupInfo)
+
+    def test_get_basebackup_directory(self):
+        """
+        Test the :meth:`get_basebackup_directory` method.
+        """
+        server = build_mocked_server()
+        base_directory = "/fake/path/"
+        backup_id = "fake_backup_id"
+        volatile_backup_info = VolatileBackupInfo(
+            server=server,
+            base_directory=base_directory,
+            backup_id=backup_id,
+        )
+        expected_directory = os.path.join(base_directory, backup_id)
+        assert volatile_backup_info.get_basebackup_directory() == expected_directory
+
+    def test_volatile_backup_info_save_not_implemented(self):
+        """
+        Test that the :meth:`save` method of :class:`VolatileBackupInfo` raises a
+        :exc:`NotImplementedError`.
+        """
+        server = build_mocked_server()
+        base_directory = "/fake/path/"
+        backup_id = "fake_backup_id"
+        volatile_backup_info = VolatileBackupInfo(
+            server=server,
+            base_directory=base_directory,
+            backup_id=backup_id,
+        )
+        with pytest.raises(
+            NotImplementedError, match="The save method is not implemented."
+        ):
+            volatile_backup_info.save()
