@@ -75,6 +75,7 @@ def build_test_backup_info(
     parent_backup_id=None,
     children_backup_ids=None,
     cluster_size=2048,
+    encryption=None,
 ):
     """
     Create an 'Ad Hoc' BackupInfo object for testing purposes.
@@ -308,6 +309,7 @@ def build_config_dictionary(config_keys=None):
         "basebackups_directory": "/some/barman/home/main/base",
         "barman_lock_directory": "/some/barman/home",
         "compression": None,
+        "compression_level": "medium",
         "config_changes_queue": "/some/barman/home/cfg_changes.queue",
         "conninfo": "host=pg01.nowhere user=postgres port=5432",
         "backup_method": "rsync",
@@ -316,6 +318,9 @@ def build_config_dictionary(config_keys=None):
         "custom_decompression_filter": None,
         "custom_compression_magic": None,
         "description": " Text with quotes ",
+        "encryption": None,
+        "encryption_key_id": None,
+        "encryption_passphrase_command": None,
         "gcp_project": None,
         "gcp_zone": None,
         "immediate_checkpoint": False,
@@ -492,8 +497,11 @@ def build_backup_manager(
     with mock.patch("barman.backup.CompressionManager"):
         manager = BackupManager(server=server)
     manager.compression_manager.unidentified_compression = None
-    manager.compression_manager.get_wal_file_info.side_effect = (
-        lambda filename: WalFileInfo.from_file(filename, manager.compression_manager)
+    manager.get_wal_file_info = mock.Mock()
+    manager.get_wal_file_info.side_effect = lambda filename: WalFileInfo.from_file(
+        filename,
+        manager.compression_manager,
+        encryption_manager=manager.encryption_manager,
     )
     server.backup_manager = manager
     return manager
